<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>CadenceGraph</name>
    <message>
        <location filename="../src/cadencegraph.cpp" line="10"/>
        <source>1/min</source>
        <translation>1/min</translation>
    </message>
    <message>
        <location filename="../src/cadencegraph.cpp" line="11"/>
        <location filename="../src/cadencegraph.h" line="13"/>
        <source>Cadence</source>
        <translation>Stegfrekvens</translation>
    </message>
    <message>
        <location filename="../src/cadencegraph.cpp" line="19"/>
        <source>Average</source>
        <translation>Genomsnittlig</translation>
    </message>
    <message>
        <location filename="../src/cadencegraph.cpp" line="21"/>
        <source>Maximum</source>
        <translation>Maximal</translation>
    </message>
</context>
<context>
    <name>ElevationGraph</name>
    <message>
        <location filename="../src/elevationgraph.cpp" line="48"/>
        <location filename="../src/elevationgraph.h" line="13"/>
        <source>Elevation</source>
        <translation>Höjd</translation>
    </message>
    <message>
        <location filename="../src/elevationgraph.cpp" line="141"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/elevationgraph.cpp" line="58"/>
        <source>Ascent</source>
        <translation>Stigning</translation>
    </message>
    <message>
        <location filename="../src/elevationgraph.cpp" line="60"/>
        <source>Descent</source>
        <translation>Nedstigning</translation>
    </message>
    <message>
        <location filename="../src/elevationgraph.cpp" line="64"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../src/elevationgraph.cpp" line="144"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/elevationgraph.cpp" line="62"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>ExportDialog</name>
    <message>
        <location filename="../src/exportdialog.cpp" line="120"/>
        <source>Export to PDF</source>
        <translation>Exportera till PDF</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="25"/>
        <source>PDF files (*.pdf);;All files (*)</source>
        <translation>PDF-filer (*.pdf);;Alla filer (*)</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="38"/>
        <source>Portrait</source>
        <translation>Stående</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="39"/>
        <source>Landscape</source>
        <translation>Liggande</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="83"/>
        <source>Page size:</source>
        <translation>Sidstorlek:</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="84"/>
        <source>Orientation:</source>
        <translation>Orientering:</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="80"/>
        <source>Page Setup</source>
        <translation>Sidinställning</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="52"/>
        <source>in</source>
        <translation>i</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="52"/>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="85"/>
        <source>Margins:</source>
        <translation>Marginaler:</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="91"/>
        <source>File:</source>
        <translation>Fil:</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="98"/>
        <source>Output file</source>
        <translation>Utdatafil</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="105"/>
        <source>Export</source>
        <translation>Exportera</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="127"/>
        <location filename="../src/exportdialog.cpp" line="137"/>
        <location filename="../src/exportdialog.cpp" line="142"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="127"/>
        <source>No output file selected.</source>
        <translation>Ingen utdatafil vald.</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="137"/>
        <source>%1 is a directory.</source>
        <translation>%1 är en mapp.</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="142"/>
        <source>%1 is not writable.</source>
        <translation>%1 är skrivskyddad.</translation>
    </message>
</context>
<context>
    <name>FileSelectWidget</name>
    <message>
        <location filename="../src/fileselectwidget.cpp" line="38"/>
        <source>Select file</source>
        <translation>Välj fil</translation>
    </message>
</context>
<context>
    <name>Format</name>
    <message>
        <location filename="../src/format.cpp" line="22"/>
        <location filename="../src/format.cpp" line="43"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/format.cpp" line="25"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/format.cpp" line="29"/>
        <location filename="../src/format.cpp" line="40"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/format.cpp" line="32"/>
        <source>km</source>
        <translation>km</translation>
    </message>
</context>
<context>
    <name>GUI</name>
    <message>
        <location filename="../src/gui.cpp" line="578"/>
        <source>GPXSee is distributed under the terms of the GNU General Public License version 3. For more info about GPXSee visit the project homepage at </source>
        <translation>GPXSee distribueras under vilkoren för GNU General Public License version 3. För mer info om GPXSee, besök hemsidan på </translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="650"/>
        <source>Open file</source>
        <translation>Öppna fil</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="740"/>
        <source>Open POI file</source>
        <translation>Öppna POI-fil</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="237"/>
        <source>Open</source>
        <translation>Öppna</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="221"/>
        <source>Quit</source>
        <translation>Avsluta</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="229"/>
        <location filename="../src/gui.cpp" line="594"/>
        <location filename="../src/gui.cpp" line="595"/>
        <source>Keyboard controls</source>
        <translation>Snabbtangenter</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="253"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="259"/>
        <source>Reload</source>
        <translation>Uppdatera</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="508"/>
        <source>Show</source>
        <translation>Visa</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="426"/>
        <location filename="../src/gui.cpp" line="502"/>
        <source>File</source>
        <translation>Arkiv</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="105"/>
        <source>FIT files (*.fit)</source>
        <translation>FIT-filer (*.fit)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="106"/>
        <source>IGC files (*.igc)</source>
        <translation>IGC-filer (*.igc)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="107"/>
        <source>NMEA files (*.nmea)</source>
        <translation>NMEA-filer (*.nmea)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="227"/>
        <location filename="../src/gui.cpp" line="617"/>
        <location filename="../src/gui.cpp" line="618"/>
        <source>Data sources</source>
        <translation>Datakällor</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="267"/>
        <source>Load POI file</source>
        <translation>Läs in POI-fil</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="270"/>
        <source>Close POI files</source>
        <translation>Stäng POI-filer</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="272"/>
        <source>Overlap POIs</source>
        <translation>Överlappa POI:er</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="276"/>
        <source>Show POI labels</source>
        <translation>Visa POI-namn</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="281"/>
        <source>Show POIs</source>
        <translation>Visa POI:er</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="290"/>
        <source>Show map</source>
        <translation>Visa karta</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="297"/>
        <source>Clear tile cache</source>
        <translation>Rensa kart-cache</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="306"/>
        <location filename="../src/gui.cpp" line="310"/>
        <location filename="../src/gui.cpp" line="606"/>
        <source>Next map</source>
        <translation>Nästa karta</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="317"/>
        <source>Show tracks</source>
        <translation>Visa spår</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="321"/>
        <source>Show routes</source>
        <translation>Visa rutter</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="325"/>
        <source>Show waypoints</source>
        <translation>Visa vägpunkter</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="329"/>
        <source>Waypoint labels</source>
        <translation>Vägpunktsnamn</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="340"/>
        <source>Show graphs</source>
        <translation>Visa diagram</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="362"/>
        <source>Show grid</source>
        <translation>Visa stödlinjer</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="368"/>
        <source>Show toolbars</source>
        <translation>Visa verktygsfält</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="374"/>
        <source>Total time</source>
        <translation>Total tid</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="379"/>
        <location filename="../src/gui.cpp" line="893"/>
        <source>Moving time</source>
        <translation>Förflyttningstid</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="386"/>
        <source>Metric</source>
        <translation>Meter</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="391"/>
        <source>Imperial</source>
        <translation>Imperial</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="397"/>
        <source>Fullscreen mode</source>
        <translation>Helskärmsläge</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="403"/>
        <source>Options...</source>
        <translation>Alternativ...</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="408"/>
        <source>Next</source>
        <translation>Nästa</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="411"/>
        <source>Previous</source>
        <translation>Föregående</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="415"/>
        <source>Last</source>
        <translation>Sista</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="418"/>
        <source>First</source>
        <translation>Första</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="440"/>
        <source>Map</source>
        <translation>Karta</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="447"/>
        <source>Graph</source>
        <translation>Diagram</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="455"/>
        <source>POI</source>
        <translation>POI</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="456"/>
        <source>POI files</source>
        <translation>POI-filer</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="467"/>
        <source>Data</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="468"/>
        <source>Display</source>
        <translation>Visa</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="476"/>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="480"/>
        <source>Units</source>
        <translation>Enhet</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="489"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="607"/>
        <source>Previous map</source>
        <translation>Föregående karta</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="620"/>
        <source>Online maps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="621"/>
        <source>Online map URLs are read on program startup from the following file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="631"/>
        <source>Ofline maps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="632"/>
        <source>Offline maps are loaded on program startup from the following directory:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="635"/>
        <source>The expected structure is one map/atlas in a separate subdirectory. Supported map formats are OziMap image-based maps and tiled TrekBuddy maps/atlases (tared and non-tared).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="1091"/>
        <source>No files loaded</source>
        <translation>Inga filer inlästa</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/gui.cpp" line="1095"/>
        <source>%n files</source>
        <translation>
            <numerusform>%n filer</numerusform>
            <numerusform>%n filer</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="106"/>
        <source>GPX files (*.gpx)</source>
        <translation>GPX-filer (*.gpx)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="108"/>
        <source>TCX files (*.tcx)</source>
        <translation>TCX-filer (*.tcx)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="107"/>
        <source>KML files (*.kml)</source>
        <translation>KML-filer (*.kml)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="105"/>
        <source>CSV files (*.csv)</source>
        <translation>CSV-filer (*.csv)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="108"/>
        <source>All files (*)</source>
        <translation>Alla filer (*)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="879"/>
        <location filename="../src/gui.cpp" line="882"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="871"/>
        <source>Routes</source>
        <translation>Rutter</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="597"/>
        <source>Next file</source>
        <translation>Nästa fil</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="575"/>
        <source>Version </source>
        <translation>Version </translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="242"/>
        <source>Print...</source>
        <translation>Skriv ut...</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="247"/>
        <source>Export to PDF...</source>
        <translation>Exportera till PDF...</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="873"/>
        <source>Waypoints</source>
        <translation>Vägpunkter</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="599"/>
        <source>Previous file</source>
        <translation>Föregående fil</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="104"/>
        <source>Supported files (*.csv *.fit *.gpx *.igc *.kml *.nmea *.tcx)</source>
        <translation>Filer som stöds (*.csv *.fit *.gpx *.igc *.kml *.nmea *.tcx)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="333"/>
        <source>Route waypoints</source>
        <translation>Ruttvägpunkter</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="601"/>
        <source>First file</source>
        <translation>Första filen</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="603"/>
        <source>Last file</source>
        <translation>Sista filen</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="604"/>
        <source>Append modifier</source>
        <translation>Tillämpa modifierare</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="624"/>
        <source>The file format is one map entry per line, consisting of the map name and tiles URL delimited by a TAB character. The tile X and Y coordinates are replaced with $x and $y in the URL and the zoom level is replaced with $z. An example map file could look like:</source>
        <translation>Filformatet är en kartpost per rad, bestående av kartnamn och kartrutans URL, avgränsade med ett TAB-tecken. Kartrutans X- och Y-koordinater ersätts med $x och $y i URL:en och zoomnivån ersätts med $z. Exempel på en kartfil kan se ut så här:</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="640"/>
        <source>To make GPXSee load a POI file automatically on startup, add the file to the following directory:</source>
        <translation>För att GPXSee skall läsa in en POI-fil automatiskt vid programstart, läggs filen i följande mapp:</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="729"/>
        <source>Error loading data file:</source>
        <translation>Fel vid inläsning av datafil:</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="732"/>
        <location filename="../src/gui.cpp" line="757"/>
        <source>Line: %1</source>
        <translation>Rad: %1</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="754"/>
        <source>Error loading POI file:</source>
        <translation>Fel vid inläsning av POI-fil:</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="865"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="869"/>
        <source>Tracks</source>
        <translation>Spår</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="232"/>
        <location filename="../src/gui.cpp" line="574"/>
        <source>About GPXSee</source>
        <translation>Om GPXSee</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="513"/>
        <source>Navigation</source>
        <translation>Navigation</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="639"/>
        <source>POIs</source>
        <translation>POI:er</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="348"/>
        <location filename="../src/gui.cpp" line="889"/>
        <source>Distance</source>
        <translation>Avstånd</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="355"/>
        <location filename="../src/gui.cpp" line="477"/>
        <location filename="../src/gui.cpp" line="891"/>
        <source>Time</source>
        <translation>Tid</translation>
    </message>
</context>
<context>
    <name>GraphView</name>
    <message>
        <location filename="../src/graphview.cpp" line="108"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/graphview.cpp" line="111"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/graphview.cpp" line="116"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/graphview.cpp" line="119"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/graphview.cpp" line="125"/>
        <source>s</source>
        <translation>sek</translation>
    </message>
    <message>
        <location filename="../src/graphview.cpp" line="128"/>
        <source>min</source>
        <translation>min</translation>
    </message>
    <message>
        <location filename="../src/graphview.cpp" line="131"/>
        <source>h</source>
        <translation>tim</translation>
    </message>
    <message>
        <location filename="../src/graphview.cpp" line="60"/>
        <location filename="../src/graphview.cpp" line="157"/>
        <source>Distance</source>
        <translation>Avstånd</translation>
    </message>
    <message>
        <location filename="../src/graphview.cpp" line="159"/>
        <source>Time</source>
        <translation>Tid</translation>
    </message>
</context>
<context>
    <name>HeartRateGraph</name>
    <message>
        <location filename="../src/heartrategraph.cpp" line="11"/>
        <location filename="../src/heartrategraph.h" line="13"/>
        <source>Heart rate</source>
        <translation>Hjärtfrekvens</translation>
    </message>
    <message>
        <location filename="../src/heartrategraph.cpp" line="10"/>
        <source>1/min</source>
        <translation>1/min</translation>
    </message>
    <message>
        <location filename="../src/heartrategraph.cpp" line="19"/>
        <source>Average</source>
        <translation>Medel</translation>
    </message>
    <message>
        <location filename="../src/heartrategraph.cpp" line="21"/>
        <source>Maximum</source>
        <translation>Max</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../src/optionsdialog.cpp" line="34"/>
        <source>Base color:</source>
        <translation>Basfärg:</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="35"/>
        <source>Palette shift:</source>
        <translation>Palettskiftning:</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="47"/>
        <source>Track width:</source>
        <translation>Spårtjocklek:</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="48"/>
        <source>Track style:</source>
        <translation>Spårstil:</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="50"/>
        <source>Tracks</source>
        <translation>Spår</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="60"/>
        <source>Route width:</source>
        <translation>Ruttjocklek:</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="61"/>
        <source>Route style:</source>
        <translation>Ruttstil:</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="63"/>
        <source>Routes</source>
        <translation>Rutter</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="67"/>
        <location filename="../src/optionsdialog.cpp" line="99"/>
        <source>Use anti-aliasing</source>
        <translation>Använd kantutjämning</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="97"/>
        <source>Line width:</source>
        <translation>Linjetjocklek:</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="113"/>
        <source>Colors</source>
        <translation>Färger</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="114"/>
        <source>Paths</source>
        <translation>Sökvägar</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="115"/>
        <location filename="../src/optionsdialog.cpp" line="183"/>
        <source>Graphs</source>
        <translation>Diagram</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="127"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="130"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="134"/>
        <source>POI radius:</source>
        <translation>POI-radie:</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="140"/>
        <location filename="../src/optionsdialog.cpp" line="224"/>
        <source>POI</source>
        <translation>POI</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="147"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="149"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="151"/>
        <source>Distance</source>
        <translation>Avstånd</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="153"/>
        <source>Time</source>
        <translation>Tid</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="155"/>
        <source>Moving time</source>
        <translation>Förflyttningstid</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="157"/>
        <source>Item count (&gt;1)</source>
        <translation>Objektantal (&gt;1)</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="172"/>
        <source>Separate graph page</source>
        <translation>Separat diagramsida</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="182"/>
        <source>Header</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="190"/>
        <source>Use OpenGL</source>
        <translation>Använd OpenGL</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="206"/>
        <location filename="../src/optionsdialog.cpp" line="227"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="222"/>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="225"/>
        <source>Print &amp; Export</source>
        <translation>Utskrift &amp; Export</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="254"/>
        <source>Options</source>
        <translation>Alternativ</translation>
    </message>
</context>
<context>
    <name>PowerGraph</name>
    <message>
        <location filename="../src/powergraph.cpp" line="10"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/powergraph.cpp" line="11"/>
        <location filename="../src/powergraph.h" line="13"/>
        <source>Power</source>
        <translation>Kraft</translation>
    </message>
    <message>
        <location filename="../src/powergraph.cpp" line="19"/>
        <source>Average</source>
        <translation>Medel</translation>
    </message>
    <message>
        <location filename="../src/powergraph.cpp" line="21"/>
        <source>Maximum</source>
        <translation>Max</translation>
    </message>
</context>
<context>
    <name>RouteItem</name>
    <message>
        <location filename="../src/routeitem.cpp" line="15"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../src/routeitem.cpp" line="17"/>
        <source>Description</source>
        <translation>Beskrivning</translation>
    </message>
    <message>
        <location filename="../src/routeitem.cpp" line="18"/>
        <source>Distance</source>
        <translation>Avstånd</translation>
    </message>
</context>
<context>
    <name>ScaleItem</name>
    <message>
        <location filename="../src/scaleitem.cpp" line="81"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/scaleitem.cpp" line="82"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/scaleitem.cpp" line="84"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/scaleitem.cpp" line="85"/>
        <source>m</source>
        <translation>m</translation>
    </message>
</context>
<context>
    <name>SpeedGraph</name>
    <message>
        <location filename="../src/speedgraph.cpp" line="13"/>
        <location filename="../src/speedgraph.h" line="14"/>
        <source>Speed</source>
        <translation>Hastighet</translation>
    </message>
    <message>
        <location filename="../src/speedgraph.cpp" line="79"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/speedgraph.cpp" line="21"/>
        <source>Average</source>
        <translation>Medel</translation>
    </message>
    <message>
        <location filename="../src/speedgraph.cpp" line="23"/>
        <source>Maximum</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/speedgraph.cpp" line="82"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
</context>
<context>
    <name>TemperatureGraph</name>
    <message>
        <location filename="../src/temperaturegraph.cpp" line="11"/>
        <location filename="../src/temperaturegraph.h" line="13"/>
        <source>Temperature</source>
        <translation>Temperatur</translation>
    </message>
    <message>
        <location filename="../src/temperaturegraph.cpp" line="19"/>
        <source>Average</source>
        <translation>Medel</translation>
    </message>
    <message>
        <location filename="../src/temperaturegraph.cpp" line="21"/>
        <source>Minimum</source>
        <translation>Min</translation>
    </message>
    <message>
        <location filename="../src/temperaturegraph.cpp" line="23"/>
        <source>Maximum</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/temperaturegraph.cpp" line="81"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/temperaturegraph.cpp" line="85"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>TrackItem</name>
    <message>
        <location filename="../src/trackitem.cpp" line="13"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../src/trackitem.cpp" line="15"/>
        <source>Description</source>
        <translation>Beskrivning</translation>
    </message>
    <message>
        <location filename="../src/trackitem.cpp" line="16"/>
        <source>Distance</source>
        <translation>Avstånd</translation>
    </message>
    <message>
        <location filename="../src/trackitem.cpp" line="18"/>
        <source>Total time</source>
        <translation>Total tid</translation>
    </message>
    <message>
        <location filename="../src/trackitem.cpp" line="20"/>
        <source>Moving time</source>
        <translation>Förflyttningstid</translation>
    </message>
    <message>
        <location filename="../src/trackitem.cpp" line="22"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
</context>
<context>
    <name>WaypointItem</name>
    <message>
        <location filename="../src/waypointitem.cpp" line="18"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../src/waypointitem.cpp" line="19"/>
        <source>Coordinates</source>
        <translation>Koordinater</translation>
    </message>
    <message>
        <location filename="../src/waypointitem.cpp" line="22"/>
        <source>Elevation</source>
        <translation>Höjd</translation>
    </message>
    <message>
        <location filename="../src/waypointitem.cpp" line="25"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../src/waypointitem.cpp" line="28"/>
        <source>Description</source>
        <translation>Beskrivning</translation>
    </message>
</context>
</TS>
